@@ -7,13 +7,9 @@ class VSphereConfig:
     kind: ClassVar[str] = "vsphere"
     user: Optional[str] = field(default=None, metadata={"description": "User name"})
     password: Optional[str] = field(default=None, metadata={"description": "Password"})
-    host: Optional[str] = field(
-        default=None, metadata={"description": "Host name/address"}
-    )
+    host: Optional[str] = field(default=None, metadata={"description": "Host name/address"})
     port: int = field(default=443, metadata={"description": "TCP port"})
     insecure: bool = field(
         default=True,
-        metadata={
-            "description": "Allow insecure connection. Do not verify certificates."
-        },
+        metadata={"description": "Allow insecure connection. Do not verify certificates."},
     )
